/*
 *
 * FileListPrinter (file-list-printer.js)
 * Author: nmatpt
 *
 */

(function() {
  var printerUtils = require('./printer-utils.js').PrinterUtils;
  var Utils = require('./utils.js').Utils;

  var hoganUtils;

  var baseTemplatesPath = 'file-summary';
  var iconsBaseTemplatesPath = 'icon';

  function FileListPrinter(config) {
    this.config = config;

    var HoganJsUtils = require('./hoganjs-utils.js').HoganJsUtils;
    hoganUtils = new HoganJsUtils(config);
  }

  FileListPrinter.prototype.generateFileList = function(diffFiles) {
    var lineTemplate = hoganUtils.template(baseTemplatesPath, 'line');

    var files = diffFiles.map(function(file) {
      if (!global.fileDisplayMap[file.newName]) {
        return '';
      }
      var fileTypeName = printerUtils.getFileTypeIcon(file);
      var iconTemplate = hoganUtils.template(iconsBaseTemplatesPath, fileTypeName);

      return lineTemplate.render({
        fileHtmlId: printerUtils.getHtmlId(file),
        oldName: file.oldName,
        newName: file.newName,
        fileName: printerUtils.getDiffName(file),
        deletedLines: '-' + file.deletedLines,
        addedLines: '+' + file.addedLines
      }, {
        fileIcon: iconTemplate
      });
    }).join('\n');

    const effectiveChangedLines = global.coveredDiffStatementNewLines + global.uncoveredDiffStatementNewLines;
    const diffStatementCoverageRate = effectiveChangedLines === 0 ? 100 : parseFloat((global.coveredDiffStatementNewLines / effectiveChangedLines * 100).toFixed(2));
    const {
      coveredLines,
      uncoveredLines,
      overallLineCoverageRate
    } = Utils.getOverallLineCoverageRate(global.coverage);
    global.coveredLines = coveredLines;
    global.uncoveredLines = uncoveredLines;
    global.overallStatementCoverageRate = overallLineCoverageRate;
    return hoganUtils.render(baseTemplatesPath, 'wrapper', {
      filesNumber: diffFiles.filter(e => !!global.fileDisplayMap[e.newName]).length,
      files: files,
      diffStatementNewLines: global.diffStatementNewLines,
      coveredDiffStatementNewLines: global.coveredDiffStatementNewLines,
      uncoveredDiffStatementNewLines: global.uncoveredDiffStatementNewLines,
      nonExecutableDiffStatementNewLines: global.nonExecutableDiffStatementNewLines,
      effectiveDiffStatementNewLines: global.coveredDiffStatementNewLines + global.uncoveredDiffStatementNewLines,
      diffStatementCoverageRate,
      coveredLines: global.coveredLines,
      uncoveredLines: global.uncoveredLines,
      allLines: global.coveredLines + global.uncoveredLines,
      overallStatementCoverageRate: global.overallStatementCoverageRate,
      displayMode: global.displayMode
    });
  };

  module.exports.FileListPrinter = FileListPrinter;
})();
